# mypykaizen

Wrapper around mypy which prevents the number of typecheck errors from increasing
but which does not force you to fix them all.

Start using and enforcing mypy type checking without first having to fix ALL the errors up front.
This tool enforces that the total number of errors is only allowed to go down or stay the same.

Currently experimental.
